# Generated by Django 3.0.5 on 2020-08-24 22:34

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.documents.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
    ]

    operations = [
        migrations.CreateModel(
            name='HeaderPage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='This option allows you to create different menus for different pages', max_length=255, verbose_name='Name header')),
                ('logo_type', models.CharField(choices=[('text', 'Texto'), ('image', 'Imagen')], default='text', max_length=10, verbose_name='Logo type')),
                ('text_logo', models.CharField(blank=True, max_length=100, null=True, verbose_name='Text Logo')),
                ('header_fixed', models.BooleanField(default=True, verbose_name='Header fixed?')),
                ('navigation', wagtail.core.fields.StreamField([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página')), ('sub_links', wagtail.core.blocks.StreamBlock([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página'))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento'))]))], label='Sub menú', required=False)), ('open_page_new_window', wagtail.core.blocks.BooleanBlock(default=False, help_text='Select if you want to open in a new tab when user clicks', label='Open in a new page', required=False))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False)), ('sub_links', wagtail.core.blocks.StreamBlock([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página'))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento'))]))], label='Sub menú', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento')), ('sub_links', wagtail.core.blocks.StreamBlock([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página'))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento'))]))], label='Sub menú', required=False))]))], blank=True, null=True)),
                ('image_logo', models.ForeignKey(blank=True, help_text='Max height 50px', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image logo')),
            ],
            options={
                'verbose_name': 'Header page',
                'verbose_name_plural': 'Headers Page',
            },
        ),
    ]
